==> Acme-MetaSyntactic-Themes-1.000.tar.gz: Acme-MetaSyntactic-Themes-1.000/lib/Acme/MetaSyntactic/amber.pm <==
package Acme::MetaSyntactic::amber;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::amber - The Amber theme

=head1 DESCRIPTION

This theme pays homage to the 10-book Amber fantasy series,
written by Roger Zelazny. The list contains names of
characters, things and places from the series, as well as the name
of the author.

=head1 CONTRIBUTOR

Offer Kaye.

Introduced in Acme-MetaSyntactic version 0.18, published on April 18, 2005.

Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
published on May 7, 2012.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Amber Arbor_House Arden Arkans Arthur Avalon Avernus Bances Bayle
Baylesport Begma Belissa_Minobee Benedict Bill_Roth Bleys Borel Borquist
Brand Cabra Cade Caine Chinaway Clarissa Coral Corwin Courts_of_Chaos
Cymnea Dalt Dan_Martinez Dara Dave Deela Deiga Delwin Dertha_Gannel
Despil Dierdre Dik Doyle Dretha_Gannel Droppa_Ma_Pantz Dworkin Dybele
Ed_Wellen Eregnor Eric Faiella_Bionin Ferla_Quist Finndo Fiona Flora
Frakir Gail_Lampron Ganelon Garnath_Valley George_Hansen Gerard Ghostweel
Gilva Glait Glemdenning Gramble Grayswandir Gride Grove_Of_The_Unicorn
Gryll Harla Heerat Hendon Hugi Isles_Of_The_Sun Jamie Jasra Jasrick
Jaston Jidrash John Jopin Julia Julian Jurt Kasman Kergma Kinta Kolvir
Lancelot Larsus_Minobee Lintra Llewella Logrus Lorraine Luke Mandor Martin
Meg_Delvin Melkin Menillan Merlin Michel_Focault Mirelle Moins Moire
Morganthe Morgenstern Moris_Bailey Nayda Oberon Oisen Orguz Osric Pattern
Paulette Random Rebma Rein Rhanda Rick_Kinsky Rilga Rinaldo Roderick
Roger Roger_Zelazny Rolovians Sand Sawall Scrof Sharu_Garul Snake Star
Strygalldwir Suhuy Swayvill Tecys Texorami Thoben Tir_na_Nogth Tmer Tubble
Unicorne Uther Vialle Victor_Melman Vinta_Bayle Werewindle Wixer Ygg

==> Acme-MetaSyntactic-Themes-1.047.tar.gz: Acme-MetaSyntactic-Themes-1.047/lib/Acme/MetaSyntactic/amber.pm <==
package Acme::MetaSyntactic::amber;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::amber - The Amber theme

=head1 DESCRIPTION

This theme pays homage to the 10-book Amber fantasy series,
written by Roger Zelazny. The list contains names of
characters, things and places from the series, as well as the name
of the author.

=head1 CONTRIBUTOR

Offer Kaye

=head1 CHANGES

=over 4

=item *

2012-05-07 - v1.000

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2005-04-18

Introduced in Acme-MetaSyntactic version 0.18.

=item *

2005-03-23

Submitted by Offer Kaye.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Amber Arbor_House Arden Arkans Arthur Avalon Avernus Bances Bayle
Baylesport Begma Belissa_Minobee Benedict Bill_Roth Bleys Borel Borquist
Brand Cabra Cade Caine Chinaway Clarissa Coral Corwin Courts_of_Chaos
Cymnea Dalt Dan_Martinez Dara Dave Deela Deiga Delwin Dertha_Gannel
Despil Dierdre Dik Doyle Dretha_Gannel Droppa_Ma_Pantz Dworkin Dybele
Ed_Wellen Eregnor Eric Faiella_Bionin Ferla_Quist Finndo Fiona Flora
Frakir Gail_Lampron Ganelon Garnath_Valley George_Hansen Gerard Ghostweel
Gilva Glait Glemdenning Gramble Grayswandir Gride Grove_Of_The_Unicorn
Gryll Harla Heerat Hendon Hugi Isles_Of_The_Sun Jamie Jasra Jasrick
Jaston Jidrash John Jopin Julia Julian Jurt Kasman Kergma Kinta Kolvir
Lancelot Larsus_Minobee Lintra Llewella Logrus Lorraine Luke Mandor Martin
Meg_Delvin Melkin Menillan Merlin Michel_Focault Mirelle Moins Moire
Morganthe Morgenstern Moris_Bailey Nayda Oberon Oisen Orguz Osric Pattern
Paulette Random Rebma Rein Rhanda Rick_Kinsky Rilga Rinaldo Roderick
Roger Roger_Zelazny Rolovians Sand Sawall Scrof Sharu_Garul Snake Star
Strygalldwir Suhuy Swayvill Tecys Texorami Thoben Tir_na_Nogth Tmer Tubble
Unicorne Uther Vialle Victor_Melman Vinta_Bayle Werewindle Wixer Ygg
